@@ -3,7 +3,7 @@
 # Launch awstats with -staticlinks option to build all static pages.
 # See COPYING.TXT file about AWStats GNU General Public License.
 #------------------------------------------------------------------------------
-# $Revision: 1.38 $ - $Author: eldy $ - $Date: 2009/09/05 14:35:29 $
+# $Revision: 1.31 $ - $Author: eldy $ - $Date: 2005/02/20 16:11:06 $
 
 #$|=1;
 #use warnings;		# Must be used in test mode only. This reduce a little process speed
@@ -15,7 +15,7 @@ use Time::Local;	# use Time::Local 'timelocal_nocheck' is faster but not support
 #------------------------------------------------------------------------------
 # Defines
 #------------------------------------------------------------------------------
-my $REVISION='$Revision: 1.38 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+my $REVISION='$Revision: 1.31 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
 my $VERSION="1.2 (build $REVISION)";
 
 # ---------- Init variables --------
@@ -30,7 +30,6 @@ my $BuildDate=0;
 my $Lang;
 my $YearRequired;
 my $MonthRequired;
-my $DayRequired;
 my $Awstats='awstats.pl';
 my $AwstatsDir='';
 my $HtmlDoc='htmldoc';		# ghtmldoc.exe
@@ -45,7 +44,6 @@ my @OutputList=();
 my $FileConfig;
 my $FileSuffix;
 my $SiteConfig;
-my $DatabaseBreak;
 use vars qw/
 $ShowAuthenticatedUsers $ShowFileSizesStats $ShowScreenSizeStats $ShowSMTPErrorsStats
 $ShowEMailSenders $ShowEMailReceivers $ShowWormsStats $ShowClusterStats
@@ -55,11 +53,7 @@ $ShowRobotsStats $ShowSessionsStats $ShowPagesStats $ShowFileTypesStats
 $ShowOSStats $ShowBrowsersStats $ShowOriginStats
 $ShowKeyphrasesStats $ShowKeywordsStats $ShowMiscStats $ShowHTTPErrorsStats
 $BuildReportFormat
-@ExtraName
-@PluginsToLoad
 /;
-@ExtraName = ();
-@PluginsToLoad = ();
 # ----- Time vars -----
 use vars qw/
 $starttime
@@ -97,8 +91,8 @@ sub warning {
 	debug("$messagestring",1);
 #	if ($WarningMessages) {
 #    	if ($HTMLOutput) {
-#    		$messagestring =~ s/\n/\<br \/\>/g;
-#    		print "$messagestring<br />\n";
+#    		$messagestring =~ s/\n/\<br\>/g;
+#    		print "$messagestring<br>\n";
 #    	}
 #    	else {
 	    	print "$messagestring\n";
@@ -117,7 +111,7 @@ sub debug {
 	my $level = $_[1] || 1;
 	if ($Debug >= $level) {
 		my $debugstring = $_[0];
-		if ($ENV{"GATEWAY_INTERFACE"}) { $debugstring =~ s/^ /&nbsp&nbsp /; $debugstring .= "<br />"; }
+		if ($ENV{"GATEWAY_INTERFACE"}) { $debugstring =~ s/^ /&nbsp&nbsp /; $debugstring .= "<br>"; }
 		print localtime(time)." - DEBUG $level - $debugstring\n";
 	}
 }
@@ -227,12 +221,6 @@ sub Parse_Config {
 			while ($value =~ /__([^\s_]+(?:_[^\s_]+)*)__/) { my $var=$1; $value =~ s/__${var}__/$ENV{$var}/g; }
 		}
 
-		# Extra parameters
- 		if ($param =~ /^ExtraSectionName(\d+)/)			{ $ExtraName[$1]=$value; next; }
-
-		# Plugins
-		if ( $param =~ /^LoadPlugin/ ) { push @PluginsToLoad, $value; next; }
-
 		# If parameters was not found previously, defined variable with name of param to value
 		$$param=$value;
 	}
@@ -255,7 +243,6 @@ if ($QueryString =~ /(^|-|&)month=(year)/i) { error("month=year is a deprecated
 if ($QueryString =~ /(^|-|&)debug=(\d+)/i)			{ $Debug=$2; }
 if ($QueryString =~ /(^|-|&)configdir=([^&]+)/i)	{ $DirConfig="$2"; }
 if ($QueryString =~ /(^|-|&)config=([^&]+)/i)		{ $SiteConfig="$2"; }
-if ($QueryString =~ /(^|-|&)databasebreak=([^&]+)/i)	{ $DatabaseBreak="$2"; }
 if ($QueryString =~ /(^|-|&)awstatsprog=([^&]+)/i)	{ $Awstats="$2"; }
 if ($QueryString =~ /(^|-|&)buildpdf/i) 			{ $BuildPDF=1; }
 if ($QueryString =~ /(^|-|&)buildpdf=([^&]+)/i)		{ $HtmlDoc="$2"; }
@@ -263,11 +250,10 @@ if ($QueryString =~ /(^|-|&)staticlinksext=([^&]+)/i)	{ $StaticExt="$2"; }
 if ($QueryString =~ /(^|-|&)dir=([^&]+)/i)			{ $OutputDir="$2"; }
 if ($QueryString =~ /(^|-|&)diricons=([^&]+)/i)		{ $DirIcons="$2"; }
 if ($QueryString =~ /(^|-|&)update/i)				{ $Update=1; }
+if ($QueryString =~ /(^|-|&)date/i)					{ $BuildDate='%YY%MM%DD'; }		# For backward compatibility
 if ($QueryString =~ /(^|-|&)builddate=?([^&]*)/i)	{ $BuildDate=$2||'%YY%MM%DD'; }
 if ($QueryString =~ /(^|-|&)year=(\d\d\d\d)/i) 		{ $YearRequired="$2"; }
 if ($QueryString =~ /(^|-|&)month=(\d{1,2})/i || $QueryString =~ /(^|-|&)month=(all)/i) { $MonthRequired="$2"; }
-if ($QueryString =~ /(^|-|&)day=(\d{1,2})/i)        { $DayRequired="$2"; }
-
 if ($QueryString =~ /(^|-|&)lang=([^&]+)/i)			{ $Lang="$2"; }
 
 if ($OutputDir) { if ($OutputDir !~ /[\\\/]$/) { $OutputDir.="/"; } }
@@ -364,20 +350,11 @@ if ($ShowHTTPErrorsStats) {
 	push @OutputList,'errors404';		
 }
 #if ($ShowSMTPErrorsStats) { push @OutputList,'errors'; }
-foreach my $extranum (1..@ExtraName-1) {
-	push @OutputList,'allextra'.$extranum;
-}
-#Add plugins
-foreach ( @PluginsToLoad ) {
-	if ($_ =~ /^(geoip_[_a-z]+)\s/) { push @OutputList,'plugin_'.$1; }	# Add geoip maxmind subpages
-}
-
 
 # Launch awstats update
 if ($Update) {
 	my $command="\"$Awstats\" -config=$SiteConfig -update";
 	$command .= " -configdir=$DirConfig" if defined $DirConfig;
-	$command .= " -databasebreak=$DatabaseBreak" if defined $DatabaseBreak;
 	print "Launch update process : $command\n";
 	$retour=`$command  2>&1`;
 }
@@ -426,9 +403,8 @@ if ($BuildPDF) { $NoLoadPlugin.="tooltips,rawlog,hostinfo"; }
 my $smallcommand="\"$Awstats\" -config=$SiteConfig".($BuildPDF?" -buildpdf":"").($NoLoadPlugin?" -noloadplugin=$NoLoadPlugin":"")." -staticlinks".($OutputSuffix ne $SiteConfig?"=$OutputSuffix":"");
 if ($StaticExt && $StaticExt ne 'html')     { $smallcommand.=" -staticlinksext=$StaticExt"; }
 if ($DirIcons)      { $smallcommand.=" -diricons=$DirIcons"; }
-if ($DirConfig)     { $smallcommand.=" -configdir=$DirConfig"; }
+if ($DirConfig)   	{ $smallcommand.=" -configdir=$DirConfig"; }
 if ($Lang)          { $smallcommand.=" -lang=$Lang"; }
-if ($DayRequired)   { $smallcommand.=" -day=$DayRequired"; }
 if ($MonthRequired) { $smallcommand.=" -month=$MonthRequired"; }
 if ($YearRequired)  { $smallcommand.=" -year=$YearRequired"; }
 
@@ -459,11 +435,10 @@ for my $output (@OutputList) {
 # Build pdf file
 if ($QueryString =~ /(^|-|&)buildpdf/i) {
 #	my $pdffile=$pages[0]; $pdffile=~s/\.\w+$/\.pdf/;
-	$OutputFile=($OutputDir?$OutputDir:"")."awstats.$OutputSuffix.pdf";
-	my $command="\"$HtmlDoc\" -t pdf --webpage --quiet --no-title --textfont helvetica --left 16 --bottom 8 --top 8 --browserwidth 800 --headfootsize 8.0 --fontsize 7.0 --header xtx --footer xd/ --outfile $OutputFile @pages\n";
+	my $command="\"$HtmlDoc\" -t pdf --webpage --quiet --no-title --textfont helvetica --left 16 --bottom 8 --top 8 --browserwidth 800 --headfootsize 8.0 --fontsize 7.0 --header xtx --footer xd/ --outfile awstats.$OutputSuffix.pdf @pages\n";
 	print "Build PDF file : $command\n";
 	$retour=`$command  2>&1`;
-    my $signal_num=$? & 127;
+	my $signal_num=$? & 127;
 	my $dumped_core=$? & 128;
 	my $exit_value=$? >> 8;
 	if ($? || $retour =~ /error/) {
