@@ -6,12 +6,10 @@
 # alone for any other log analyzer.
 # See COPYING.TXT file about AWStats GNU General Public License.
 #-----------------------------------------------------------------------------
-# $Revision: 1.41 $ - $Author: eldy $ - $Date: 2008/11/15 14:58:01 $
+# $Revision: 1.31 $ - $Author: eldy $ - $Date: 2004/11/27 14:32:00 $
 
 use strict; no strict "refs";
 #use diagnostics;
-use POSIX qw( strftime );
-
 
 #-----------------------------------------------------------------------------
 # Defines
@@ -36,7 +34,7 @@ my %TmpDNSLookup = ();
 
 # ---------- Init variables --------
 use vars qw/ $REVISION $VERSION /;
-$REVISION='$Revision: 1.41 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+$REVISION='$Revision: 1.31 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
 $VERSION="1.2 (build $REVISION)";
 
 use vars qw/ $NBOFLINESFORBENCHMARK /;
@@ -44,9 +42,9 @@ $NBOFLINESFORBENCHMARK=8192;
 
 use vars qw/
 $DIR $PROG $Extension
-$Debug $ShowSteps $AddFileNum $AddFileName
+$Debug $ShowSteps $AddFileNum
 $MaxNbOfThread $DNSLookup $DNSCache $DirCgi $DirData $DNSLookupAlreadyDone
-$NbOfLinesShowsteps $AFINET $QueueCursor $StopOnFirstEof
+$NbOfLinesShowsteps $AFINET $QueueCursor
 /;
 $DIR='';
 $PROG='';
@@ -54,7 +52,6 @@ $Extension='';
 $Debug=0;
 $ShowSteps=0;
 $AddFileNum=0;
-$AddFileName=0;
 $MaxNbOfThread=0;
 $DNSLookup=0;
 $DNSCache='';
@@ -63,7 +60,6 @@ $DirData='';
 $DNSLookupAlreadyDone=0;
 $NbOfLinesShowsteps=0;
 $AFINET='';
-$StopOnFirstEof=0;
 
 # ---------- Init arrays --------
 use vars qw/
@@ -72,22 +68,15 @@ use vars qw/
 /;
 # ---------- Init hash arrays --------
 use vars qw/
-%LogFileToDo %linerecord %timerecord %corrupted
+%linerecord %timerecord %corrupted
 %QueueHostsToResolve %QueueRecords
 /;
-%LogFileToDo = %linerecord = %timerecord = %corrupted = ();
+%linerecord = %timerecord = %corrupted = ();
 %QueueHostsToResolve = %QueueRecords = ();
 
-# DRA2: the order of timerecords are kept here, each index in the array is the filerecordnumber, which
-# DRA2: is used as the key for the other hashes
-use vars qw/
-@timerecordorder
-/;
-@timerecordorder = ();
-
 # ---------- External Program variables ----------
 # For gzip compression
-my $zcat = 'gzip -cd';
+my $zcat = 'zcat';
 my $zcat_file = '\.gz$';
 # For bz2 compression
 my $bzcat = 'bzcat';
@@ -156,7 +145,7 @@ sub IsAscii {
 }
 
 #-----------------------------------------------------------------------------
-# DRA Function:     Return 1 if DNS lookup should be skipped
+# Function:     Return 1 if string contains only ascii chars
 # Input:        String
 # Return:       0 or 1
 #-----------------------------------------------------------------------------
@@ -217,9 +206,8 @@ sub WriteRecordsReadyInQueue {
 			}
 		}
 		# Record is ready, we output it.
-		if ($AddFileNum)  { print "$logfilechosen "; }
-		if ($AddFileName) { print "$LogFileToDo{$logfilechosen} "; }
-		print "$QueueRecords{$QueueCursor}\n";
+		if ($AddFileNum) { print "$logfilechosen $QueueRecords{$QueueCursor}\n"; }
+		else { print "$QueueRecords{$QueueCursor}\n"; }
 		delete $QueueRecords{$QueueCursor};
 		delete $QueueHostsToResolve{$QueueCursor};
 		$QueueCursor++;
@@ -259,8 +247,6 @@ for (0..@ARGV-1) {
 		elsif ($ARGV[$_] =~ /dnslookup/i) { $DNSLookup||=1; }
 		elsif ($ARGV[$_] =~ /showsteps/i) { $ShowSteps=1; }
 		elsif ($ARGV[$_] =~ /addfilenum/i) { $AddFileNum=1; }
-		elsif ($ARGV[$_] =~ /addfilename/i) { $AddFileName=1; }
-		elsif ($ARGV[$_] =~ /stoponfirsteof/i) { $StopOnFirstEof=1; }
 		else { print "Unknown argument $ARGV[$_] ignored\n"; }
 	}
 	else {
@@ -307,15 +293,13 @@ if (scalar @ParamFile == 0) {
 	print "  $PROG.$Extension [options] *.*\n";
 	print "  perl $PROG.$Extension [options] *.* > newfile\n";
 	print "Options:\n";
-	print "  -dnslookup      make a reverse DNS lookup on IP adresses\n";
-	print "  -dnslookup=n    same with a n parallel threads instead of serial requests\n";
-	print "  -dnscache=file  make DNS lookup from cache file first before network lookup\n";
-	print "  -showsteps      print on stderr benchmark information every $NBOFLINESFORBENCHMARK lines\n";
-	print "  -addfilenum     if used with several files, file number can be added in first\n";
-	print "  -addfilename    if used with several files, file name can be added in first\n";
-	print "                  field of output file. This can be used to add a cluster id\n";
-	print "                  when log files come from several load balanced computers.\n";
-	print "  -stoponfirsteof Stop processing when any logfile reaches end-of-file.\n";
+	print "  -dnslookup     make a reverse DNS lookup on IP adresses\n";
+	print "  -dnslookup=n   same with a n parallel threads instead of serial requests\n";
+	print "  -dnscache=file make DNS lookup from cache file first before network lookup\n";
+	print "  -showsteps     print on stderr benchmark information every $NBOFLINESFORBENCHMARK lines\n";
+	print "  -addfilenum    if used with several files, file number can be added in first\n";
+	print "                 field of output file. This can be used to add a cluster id\n";
+	print "                 when log files come from several load balanced computers.\n";
 	print "\n";
 	
 	print "This runs $PROG in command line to open one or several\n";
@@ -346,8 +330,8 @@ if (scalar @ParamFile == 0) {
 	print "WARNING: If log files are old MAC text files (lines ended with CR char), you\n";
 	print "can't run this tool on Win or Unix platforms.\n";
 	print "\n";
-	print "WARNING: Because of memory holes in ActiveState Perl version, use another\n";
-	print "Perl interpreter if you need to process large log files.\n";
+	print "WARNING: Because of important memory holes in ActiveState Perl version, use\n";
+	print "another Perl interpreter if you need to process large lof files.\n";
 	print "\n";
 	print "Now supports/detects:\n";
 	print "  Automatic detection of log format\n";
@@ -406,6 +390,7 @@ if ($DNSCache) {
 #-----------------------------------------------------------------------------
 # PROCESSING CURRENT LOG(s)
 #-----------------------------------------------------------------------------
+my %LogFileToDo=();
 my $NbOfLinesRead=0;
 my $NbOfLinesParsed=0;
 my $logfilechosen=0;
@@ -415,8 +400,8 @@ my $starttime=time();
 $cpt=1;
 foreach my $key (0..(@ParamFile-1)) {
 	if ($ParamFile[$key] !~ /\*/ && $ParamFile[$key] !~ /\?/) {
+		if ($Debug) { debug("Log file $ParamFile[$key] is added to LogFileToDo with number $cpt."); }
 
-		if ($Debug) { debug("DBG1 Log file $ParamFile[$key] is added to LogFileToDo with number $cpt."); }
 		# Check for supported compression 
 		if ($ParamFile[$key] =~ /$zcat_file/) {
 			if ($Debug) { debug("GZIP compression detected for Log file $ParamFile[$key]."); }
@@ -431,42 +416,26 @@ foreach my $key (0..(@ParamFile-1)) {
 
 		$LogFileToDo{$cpt}=@ParamFile[$key];
 		$cpt++;
-		
 	}
-    else {
-        my $DirFile=$ParamFile[$key]; $DirFile =~ s/([^\/\\]*)$//;
-        $ParamFile[$key] = $1;
-        if ($DirFile eq '') { $DirFile = '.'; }
-        $ParamFile[$key] =~ s/\./\\\./g;
-        $ParamFile[$key] =~ s/\*/\.\*/g;
-        $ParamFile[$key] =~ s/\?/\./g;
-        if ($Debug) { debug("Search for file \"$ParamFile[$key]\" into \"$DirFile\""); }
-        opendir(DIR,"$DirFile");
-        my @filearray = sort readdir DIR;
-        close DIR;
-        foreach my $i (0..$#filearray) {
-            if ("$filearray[$i]" =~ /^$ParamFile[$key]$/ && "$filearray[$i]" ne "." && "$filearray[$i]" ne "..") {
-
-                if ($Debug) { debug("DBG2 Log file $filearray[$i] is added to LogFileToDo with number $cpt."); }
-                # Check for supported compression
-                if ($filearray[$i] =~ /$zcat_file/) {
-                    if ($Debug) { debug("GZIP compression detected for Log file $filearray[$i]."); }
-                    # Modify the name to include the zcat command
-                    $LogFileToDo{$cpt}=$zcat . ' ' . "$DirFile/$filearray[$i]" . ' |';
-                }
-                elsif ($filearray[$i] =~ /$bzcat_file/) {
-                    if ($Debug) { debug("BZ2 compression detected for Log file $filearray[$i]."); }
-                    # Modify the name to include the bzcat command
-                    $LogFileToDo{$cpt}=$bzcat . ' ' . "$DirFile/$filearray[$i]" . ' |';
-                }
-                else {
-                    $LogFileToDo{$cpt}="$DirFile/$filearray[$i]";
-                }
-                $cpt++;
-                
-            }
-        }
-    }
+	else {
+		my $DirFile=$ParamFile[$key]; $DirFile =~ s/([^\/\\]*)$//;
+		$ParamFile[$key] = $1;
+		if ($DirFile eq '') { $DirFile = '.'; }
+		$ParamFile[$key] =~ s/\./\\\./g;
+		$ParamFile[$key] =~ s/\*/\.\*/g;
+		$ParamFile[$key] =~ s/\?/\./g;
+		if ($Debug) { debug("Search for file \"$ParamFile[$key]\" into \"$DirFile\""); }
+		opendir(DIR,"$DirFile");
+		my @filearray = sort readdir DIR;
+		close DIR;
+		foreach my $i (0..$#filearray) {
+			if ("$filearray[$i]" =~ /^$ParamFile[$key]$/ && "$filearray[$i]" ne "." && "$filearray[$i]" ne "..") {
+				if ($Debug) { debug("Log file $filearray[$i] is added to LogFileToDo with number $cpt."); }
+				$LogFileToDo{$cpt}="$DirFile/$filearray[$i]";
+				$cpt++;
+			}
+		}
+	}
 }
 
 # If no files to process
@@ -483,118 +452,67 @@ foreach my $logfilenb (keys %LogFileToDo) {
 }
 
 $QueueCursor=1;
-STOPONFIRSTEOF: while (1 == 1)
+while (1 == 1)
 {
-	# BEGIN Read new record
-	# For each log file if logfilechosen is 0
-	# If not, we go directly to log file instead of iterating over all keys for a match
-	#----------------------------------------------------------------------------------
-    my @readlist;
-	if($logfilechosen == 0) {
-	    @readlist = keys %LogFileToDo;
-	} else {
-	    @readlist = ($logfilechosen);
-	}
-	foreach my $logfilenb (@readlist)
-	{
-		if ($Debug) { debug("Search next record in file number $logfilenb",3); }
-		# Read chosen log file until we found a record with good date or reaching end of file
-		while (1 == 1) {
-			my $LOG="LOG$logfilenb";
-			$_=<$LOG>;	# Read new line
-			if (! $_) 
-			{							# No more records in log file number $logfilenb
-				if ($Debug) { debug(" No more records in file number $logfilenb",2); }
-				delete $LogFileToDo{$logfilenb};
-				if ($StopOnFirstEof) 
-				{
-					if ($Debug) { debug("Exiting loop due to EOF of logfile $logfilenb",1); }
-					last STOPONFIRSTEOF;
+	# BEGIN Read new record (for each log file or only for log file with record just processed)
+	#------------------------------------------------------------------------------------------
+	foreach my $logfilenb (keys %LogFileToDo) {
+		if (($logfilechosen == 0) || ($logfilechosen == $logfilenb)) {
+			if ($Debug) { debug("Search next record in file number $logfilenb",3); }
+			# Read chosen log file until we found a record with good date or reaching end of file
+			while (1 == 1) {
+				my $LOG="LOG$logfilenb";
+				$_=<$LOG>;	# Read new line
+				if (! $_) {							# No more records in log file number $logfilenb
+					if ($Debug) { debug(" No more records in file number $logfilenb",2); }
+					delete $LogFileToDo{$logfilenb};
+					last;
 				}
+
+				$NbOfLinesRead++;
+				chomp $_; s/\r$//;
+
+				if (/^#/) { next; }									# Ignore comment lines (ISS writes such comments)
+				if (/^!!/) { next; }								# Ignore comment lines (Webstar writes such comments)
+				if (/^$/) { next; }									# Ignore blank lines (With ISS: happens sometimes, with Apache: possible when editing log file)
+
+				$linerecord{$logfilenb}=$_; 
+
+				# Check filters
+				#----------------------------------------------------------------------
+
+				# Split DD/Month/YYYY:HH:MM:SS or YYYY-MM-DD HH:MM:SS or MM/DD/YY\tHH:MM:SS
+				my $year=0; my $month=0; my $day=0; my $hour=0; my $minute=0; my $second=0;
+				if ($_ =~ /(\d\d\d\d)-(\d\d)-(\d\d) (\d\d):(\d\d):(\d\d)/) { $year=$1; $month=$2; $day=$3; $hour=$4; $minute=$5; $second=$6; }
+				elsif ($_ =~ /\[(\d\d)[\/:\s](\w+)[\/:\s](\d\d\d\d)[\/:\s](\d\d)[\/:\s](\d\d)[\/:\s](\d\d) /) { $year=$3; $month=$2; $day=$1; $hour=$4; $minute=$5; $second=$6; }
+				elsif ($_ =~ /\[\w+ (\w+) (\d\d) (\d\d)[\/:\s](\d\d)[\/:\s](\d\d) (\d\d\d\d)\]/) { $year=$6; $month=$1; $day=$2; $hour=$3; $minute=$4; $second=$5; }
+
+				if ($monthnum{$month}) { $month=$monthnum{$month}; }	# Change lib month in num month if necessary
+
+				# Create $timerecord like YYYYMMDDHHMMSS
+		 		$timerecord{$logfilenb}=int("$year$month$day$hour$minute$second");
+				if ($timerecord{$logfilenb}<10000000000000) {
+					if ($Debug) { debug(" This record is corrupted (no date found)",3); }
+					$corrupted{$logfilenb}++;
+					next;
+				}
+				if ($Debug) { debug(" This is next record for file $logfilenb : timerecord=$timerecord{$logfilenb}",3); }
 				last;
 			}
-
-			$NbOfLinesRead++;
-			chomp $_; s/\r$//;
-
-			if (/^#/) { next; }									# Ignore comment lines (ISS writes such comments)
-			if (/^!!/) { next; }								# Ignore comment lines (Webstar writes such comments)
-			if (/^$/) { next; }									# Ignore blank lines (With ISS: happens sometimes, with Apache: possible when editing log file)
-
-			$linerecord{$logfilenb}=$_; 
-
-			# Check filters
-			#----------------------------------------------------------------------
-
-			# Split YYYY-MM-DD HH:MM:SS
-			#    or DD/Month/YYYY:HH:MM:SS
-			#    or MM/DD/YY\tHH:MM:SS
-			#    or 9999.999
- 			#    or Month DD HH:MM:SS
-			my $year=0; my $month=0; my $day=0; my $hour=0; my $minute=0; my $second=0;
-			if ($_ =~ /(\d\d\d\d)-(\d\d)-(\d\d)\s(\d\d):(\d\d):(\d\d)/) { $year=$1; $month=$2; $day=$3; $hour=$4; $minute=$5; $second=$6; }
-			elsif ($_ =~ /\[(\d?\d)[\/:\s](\w+)[\/:\s](\d\d\d\d)[\/:\s](\d\d)[\/:\s](\d\d)[\/:\s](\d\d) /) { $year=$3; $month=$2; $day=$1; $hour=$4; $minute=$5; $second=$6; }
-			elsif ($_ =~ /\w+ (\w+) {1,2}(\d?\d) (\d\d)[\/:\s](\d\d)[\/:\s](\d\d) (\d\d\d\d)/) { $year=$6; $month=$1; $day=$2; $hour=$3; $minute=$4; $second=$5; }
-			elsif ($_ =~ /^(\d\d\d\d+\.\d\d\d) /)
-			{
-				my $timetime = strftime('%Y-%m-%d-%T', gmtime($1));
-				$timetime =~ /(\d\d\d\d)-(\d\d)-(\d\d)-(\d\d):(\d\d):(\d\d)/;
-				$year=$1; $month=$2; $day=$3; $hour=$4; $minute=$5; $second=$6;
-			}
- 			elsif ($_ =~ /(\w+)\s\s?(\d?\d) (\d\d):(\d\d):(\d\d) /) {	# Month DD HH:MM:SS
- 				$month=$1; $day=$2; $hour=$3; $minute=$4; $second=$5;
- 				if (($monthnum{$month}>$monthnum{$nowmonth}) || ($monthnum{$month}==$monthnum{$nowmonth} &&  $day>$nowday)) {
- 					$year=$nowyear-1;
- 				}
-                else { $year=$nowyear; }
- 			}
-			if (length $day == 1) { $day = "0".$day; }
-
-			if ($monthnum{$month}) { $month=$monthnum{$month}; }	# Change lib month in num month if necessary
-
-			# Create $timerecord like YYYYMMDDHHMMSS
-	 		$timerecord{$logfilenb}=int("$year$month$day$hour$minute$second");
-			if ($timerecord{$logfilenb}<10000000000000) {
-				if ($Debug) { debug(" This record is corrupted (no date found)",3); }
-				$corrupted{$logfilenb}++;
-				next;
-			}
-			if ($Debug) { debug(" This is next record for file $logfilenb : timerecord=$timerecord{$logfilenb}",3); }
-			
-			# Sort and insert into timerecordorder, oldest at end/back of array
-			# At the beginning, timerecordorder is empty. Then beceause the first pass is
-			# a loop on each file to read each first line, the timerecordorder size is
-			# number of input files.
-			# After, each new loop, read only one new line, so timerecordorder size increase
-			# by one but decrease just after by the pop command later.
-			my $inserted=0;
-			for(my $c=$#timerecordorder; $c>=0 ; $c--) {
-			    if($timerecord{$logfilenb} <= $timerecord{$timerecordorder[$c]})
-			    {
-    				# Is older or equal than index at $c, add after
-				    $timerecordorder[$c + 1]=$logfilenb;
-				    $inserted = 1;
-				    last;
-			    } else {
-				    $timerecordorder[$c + 1]=$timerecordorder[$c];
-			    }
-			}
-			if(! $inserted) {
-			    $timerecordorder[0] = $logfilenb;
-			}
-
-			last;
 		}
 	}
 	# END Read new lines for each log file. After this, following var are filled
 	# $timerecord{$logfilenb}
-	# @timerecordorder array
 
 	# We choose which record of which log file to process
 	if ($Debug) { debug("Choose which record of which log file to process",3); }
-	$logfilechosen=pop(@timerecordorder);
-	if(!defined($logfilechosen)) { last; }              # No more record to process 
-	
+	$logfilechosen=-1;
+	my $timeref="99999999999999";
+	foreach my $logfilenb (keys %LogFileToDo) {
+		if ($Debug) { debug(" timerecord for file $logfilenb is $timerecord{$logfilenb}",4); }
+		if ($timerecord{$logfilenb} < $timeref) { $logfilechosen=$logfilenb; $timeref=$timerecord{$logfilenb} }
+	}
+	if ($logfilechosen <= 0) { last; }								# No more record to process
 	# Record is chosen
 	if ($Debug) { debug(" We choosed to qualify record of file number $logfilechosen",3); }
 	if ($Debug) { debug("  Record is $linerecord{$logfilechosen}",3); }
