@@ -19,21 +19,36 @@ use strict;no strict "refs";
 # Defines
 #-------------------------------------------------------
 use vars qw/ $REVISION $VERSION /;
-$REVISION='$Revision: 1.22 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
-$VERSION="1.1 (build $REVISION)";
+$REVISION='$Revision: 1.31 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+$VERSION="1.2 (build $REVISION)";
 
 use vars qw/
 $DIR $PROG $Extension
 $Debug
 %mail %qmaildelivery
 $help
-$mode $year $Debug
+$mode $year $lastmon $Debug
 $NBOFENTRYFOFLUSH
 $MailType
+%MonthNum
 /;
 $Debug=0;
-$NBOFENTRYFOFLUSH=8192;		# Nb or records for flush of %entry (Must be a power of 2)
+$NBOFENTRYFOFLUSH=16384;	# Nb or records for flush of %entry (Must be a power of 2)
 $MailType='';				# Mail server family (postfix, sendmail, qmail)
+%MonthNum = (
+'Jan'=>1,
+'Feb'=>2,
+'Mar'=>3,
+'Apr'=>4,
+'May'=>5,
+'Jun'=>6,
+'Jul'=>7,
+'Aug'=>8,
+'Sep'=>9,
+'Oct'=>10,
+'Nov'=>11,
+'Dec'=>12
+);
 
 
 #-------------------------------------------------------
@@ -100,7 +115,7 @@ sub trim { $_=shift;
 #
 sub OutputRecord {
 	my $year=shift;
-	my $month=shift;
+	my $month=shift;    # Jan,Feb,... or 1,2,3...
 	my $day=shift;
 	my $time=shift;
 	my $from=shift;
@@ -114,18 +129,7 @@ sub OutputRecord {
 
 	# Clean day and month
 	$day=sprintf("%02d",$day);
-	if ($month eq 'Jan') { $month = "01"; }
-	if ($month eq 'Feb') { $month = "02"; }
-	if ($month eq 'Mar') { $month = "03"; }
-	if ($month eq 'Apr') { $month = "04"; }
-	if ($month eq 'May') { $month = "05"; }
-	if ($month eq 'Jun') { $month = "06"; }
-	if ($month eq 'Jul') { $month = "07"; }
-	if ($month eq 'Aug') { $month = "08"; }
-	if ($month eq 'Sep') { $month = "09"; }
-	if ($month eq 'Oct') { $month = "10"; }
-	if ($month eq 'Nov') { $month = "11"; }
-	if ($month eq 'Dec') { $month = "12"; }
+    $month=sprintf("%02d",$MonthNum{$month}||$month);
 
 	# Clean from
 	$from=&CleanEmail($from);
@@ -212,6 +216,7 @@ HELPTEXT
 #
 # Start Processing Input Logfile
 #
+$lastmon=0;
 my $numrecord=0;
 my $numrecordforflush=0;
 while (<>) {
@@ -223,6 +228,16 @@ while (<>) {
 
 	if (/^__BREAKPOINT__/) { last; }	# For debug only
 
+	### <CJK> ###
+	my ($mon)=m/(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s/;
+	if ($mon) {
+	    $mon = $MonthNum{$mon};
+		if ($mon==12 && $lastmon==1 ){$year--;}
+		if ($mon==1 && $lastmon==12){$year++;}
+		$lastmon=$mon;
+	}
+	### </CJK> ###
+
 	if (/^#/) {
 		debug("Comment record");
 		next;
@@ -233,7 +248,9 @@ while (<>) {
 	#
 	elsif (/: client=/) {
 		$MailType||='postfix';
-		my ($id,$relay_s)=m/\w+\s+\d+\s+\d+:\d+:\d+\s+[\w\-]+\s+(?:sendmail|postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[\d+\]:\s+(.*?):\s+client=(.*)/;
+		# Example:
+		# postfix:  Jan 01 07:27:32 apollon.com postfix/smtpd[1684]: 2BC793B8A4: client=remt30.cluster1.abcde.net[209.225.8.40]
+		my ($id,$relay_s)=m/\w+\s+\d+\s+\d+:\d+:\d+\s+[\w\-\.\@]+\s+(?:sendmail|postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[\d+\]:\s+(.*?):\s+client=(.*)/;
 		$mailid=$id;
 		$mail{$id}{'relay_s'}=$relay_s;
 		debug("For id=$id, found host sender on a 'client' line: $mail{$id}{'relay_s'}");
@@ -245,20 +262,30 @@ while (<>) {
 	elsif (/: reject/) {
 		$MailType||='postfix';
 		# Example: 
-		# postfix:  Jan 01 04:19:04 apollon postfix/smtpd[26553]: 1954F3B8A4: reject: RCPT from unknown[80.245.33.2]: 450 <partenaires@chiensderace.com>: User unknown in local recipient table; from=<httpd@fozzy2.dpi-europe.fr> to=<partenaires@chiensderace.com> proto=ESMTP helo=<fozzy2.dpi-europe.fr>
-		# postfix:  Jan 01 04:26:39 halley postfix/smtpd[9245]: reject: RCPT from unknown[203.156.32.33]: 554 <charitha99@yahoo.com>: Recipient address rejected: Relay access denied; from=<1126448365@aol.com> to=<charitha99@yahoo.com>
-		my ($mon,$day,$time,$id,$code,$from,$to)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-]+\s+(?:postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[\d+\]:\s+(.*?):\s+(.*)\s+from=([^\s,]*)\s+to=([^\s,]*)/;
-		$mailid=($id eq 'reject'?'999':$id);	# id not provided in log, we take '999'
-		# $code='reject: RCPT from c66.191.66.89.dul.mn.charter.com[66.191.66.89]: 450 <partenaires@chiensderace.com>: User unknown in local recipient table;'
-		#    or 'reject: RCPT from unknown[203.156.32.33]: 554 <charitha99@yahoo.com>: Recipient address rejected: Relay access denied;'
+		# postfix ?.? :  Jan 01 12:00:00 halley postfix/smtpd[9245]: reject: RCPT from unknown[203.156.32.33]: 554 <userx@yahoo.com>: Recipient address rejected: Relay access denied; from=<sender@aol.com> to=<userx@yahoo.com>
+        # postfix 2.1+:  Jan 01 12:00:00 localhost postfix/smtpd[11120]: NOQUEUE: reject: RCPT from unknown[62.205.124.145]: 450 Client host rejected: cannot find your hostname, [62.205.124.145]; from=<sender@msn.com> to=<usery@yahoo.com> proto=ESMTP helo=<xxx.com>
+		# postfix ?.? :  Jan 01 12:00:00 apollon postfix/smtpd[26553]: 1954F3B8A4: reject: RCPT from unknown[80.245.33.2]: 450 <usery@yahoo.com>: User unknown in local recipient table; from=<sender@msn.com> to=<usery@yahoo.com> proto=ESMTP helo=<xxx.com>
+		my ($mon,$day,$time,$id,$code,$from,$to)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-\.\@]+\s+(?:postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[\d+\]:\s+(.*?):\s+(.*)\s+from=([^\s,]*)\s+to=([^\s,]*)/;
+		# postfix:	Jan 01 14:10:16 juni postfix/smtpd[2568]: C34ED1432B: reject: RCPT from relay2.tp2rc.edu.tw[163.28.32.177]: 450 <linda@trieger.org>: User unknown in local recipient table; from=<> proto=ESMTP helo=<rmail.nccu.edu.tw>
+		if (! $mon) { ($mon,$day,$time,$id,$code,$from)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-\.\@]+\s+(?:postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[\d+\]:\s+(.*?):\s+(.*)\s+from=([^\s,]*)/; }
+		$mailid=($id eq 'reject' || $id eq 'NOQUEUE'?'999':$id);	# id not provided in log, we take '999'
 		if ($mailid) {
+			# $code='reject: RCPT from unknown[203.156.32.33]: 554 <userx@yahoo.com>: Recipient address rejected: Relay access denied;'
+		    #    or 'reject: RCPT from unknown[62.205.124.145]: 450 Client host rejected: cannot find your hostname, [62.205.124.145]; from=<sender@msn.com> to=<usery@yahoo.com> proto=ESMTP helo=<xxx.com>'
+			#    or 'reject: RCPT from unknown[80.245.33.2]: 450 <usery@yahoo.com>: User unknown in local recipient table;'
 			if ($code =~ /\s+(\d\d\d)\s+/) { $mail{$mailid}{'code'}=$1; }
 			else { $mail{$mailid}{'code'}=999; }	# Unkown error
-			if (! $mail{$mailid}{'relay_s'} &&  $code =~ /from\s+([^\s]+)\s+/) {
+			if (! $mail{$mailid}{'relay_s'} && $code =~ /from\s+([^\s]+)\s+/) {
 				$mail{$mailid}{'relay_s'}=&trim($1);
 			}
 			$mail{$mailid}{'from'}=&trim($from);
-			$mail{$mailid}{'to'}=&trim($to);
+			if ($to) { 
+				$mail{$mailid}{'to'}=&trim($to);
+			}
+			elsif ($code =~ /<(.*)>/) {
+				$mail{$mailid}{'to'}=&trim($1);
+			}
+			$mail{$mailid}{'year'}=$year; ### <CJK>###
 			$mail{$mailid}{'mon'}=$mon;
 			$mail{$mailid}{'day'}=$day;
 			$mail{$mailid}{'time'}=$time;
@@ -273,12 +300,13 @@ while (<>) {
 		$MailType||='postfix';
 		# Example: 
 		# postfix:  Sep  9 18:24:23 halley postfix/local[22003]: 12C6413EC9: to=<etavidian@partenor.com>, relay=local, delay=0, status=bounced (unknown user: "etavidian")
-		my ($mon,$day,$time,$id,$to,$relay_r)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-]+\s+(?:postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[\d+\]:\s+(.*?):\s+to=([^\s,]*)[\s,]+relay=([^\s,]*)/;
+		my ($mon,$day,$time,$id,$to,$relay_r)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-\.\@]+\s+(?:postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[\d+\]:\s+(.*?):\s+to=([^\s,]*)[\s,]+relay=([^\s,]*)/;
 		$mailid=($id eq 'reject'?'999':$id);	# id not provided in log, we take '999'
 		if ($mailid) {
 			$mail{$mailid}{'code'}=999;	# Unkown error (bounced)
 			$mail{$mailid}{'to'}=&trim($to);
 			$mail{$mailid}{'relay_r'}=&trim($relay_r);
+			$mail{$mailid}{'year'}=$year; ### <CJK>###
 			$mail{$mailid}{'mon'}=$mon;
 			$mail{$mailid}{'day'}=$day;
 			$mail{$mailid}{'time'}=$time;
@@ -299,9 +327,9 @@ while (<>) {
 		# sendmail:	Jan 10 07:37:48 smtp sendmail[32440]: ruleset=check_relay, arg1=[211.228.26.114], arg2=211.228.26.114, relay=[211.228.26.114], reject=554 5.7.1 Rejected 211.228.26.114 found in dnsbl.sorbs.net
 		# sendmail: Jan 10 07:37:08 smtp sendmail[32439]: ruleset=check_relay, arg1=235.Red-213-97-175.pooles.rima-tde.net, arg2=213.97.175.235, relay=235.Red-213-97-175.pooles.rima-tde.net [213.97.175.235], reject=550 5.7.1 Mail from 213.97.175.235 refused. Rejected for bad WHOIS info on IP of your SMTP server - see http://www.rfc-ignorant.org/
 		# sendmail: Jan 10 17:15:42 smtp sendmail[12770]: ruleset=check_relay, arg1=[63.218.84.21], arg2=63.218.84.21, relay=[63.218.84.21], reject=553 5.3.0 Rejected - see http://spamhaus.org/
-		my ($mon,$day,$time,$id,$ruleset,$arg,$relay_s,$code)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-]+\s+(?:sendmail|sm-mta)\[\d+\][:\s]*(.*?):\sruleset=(\w+),\s+arg1=(.*),\s+relay=(.*),\s+(reject=.*)/;
+		my ($mon,$day,$time,$id,$ruleset,$arg,$relay_s,$code)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-\.\@]+\s+(?:sendmail|sm-mta)\[\d+\][:\s]*(.*?):\sruleset=(\w+),\s+arg1=(.*),\s+relay=(.*),\s+(reject=.*)/;
 		# sendmail: Jan 10 18:00:34 smtp sendmail[5759]: i04Axx2c005759: Milter: data, reject=511 Virus found in email!
-		if (! $mon) { ($mon,$day,$time,$id,$ruleset,$code)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-]+\s+(?:sendmail|sm-mta)\[\d+\]:\s+(.*?):\s\w+:\s(\w+),\s+(reject=.*)/; }
+		if (! $mon) { ($mon,$day,$time,$id,$ruleset,$code)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-\.\@]+\s+(?:sendmail|sm-mta)\[\d+\]:\s+(.*?):\s\w+:\s(\w+),\s+(reject=.*)/; }
 		$mailid=(! $id && $mon?'999':$id);	# id not provided in log, we take '999'
 		if ($mailid) {
 			if ($ruleset eq 'check_mail') { $mail{$mailid}{'from'}=$arg; }
@@ -312,6 +340,7 @@ while (<>) {
 			# $code='reject=550 5.7.1 <amber3624@netzero.net>... Relaying denied'
 			if ($code =~ /=(\d\d\d)\s+/) { $mail{$mailid}{'code'}=$1; }
 			else { $mail{$mailid}{'code'}=999; }	# Unkown error
+			$mail{$mailid}{'year'}=$year; ### <CJK>###
 			$mail{$mailid}{'mon'}=$mon;
 			$mail{$mailid}{'day'}=$day;
 			$mail{$mailid}{'time'}=$time;
@@ -328,7 +357,7 @@ while (<>) {
 		#
 		# Matched outgoing sendmail/postfix message
 		#
-		my ($mon,$day,$time,$id,$to,$from)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-]+\s+(?:sm-mta|sendmail(?:-out|)|postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[.*?\]:\s+([^:]*):\s+to=(.*?)[,\s]+ctladdr=([^\,\s]*)/;
+		my ($mon,$day,$time,$id,$to,$fromorto)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-\.\@]+\s+(?:sm-mta|sendmail(?:-out|)|postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[.*?\]:\s+([^:]*):\s+to=(.*?)[,\s]+ctladdr=([^\,\s]*)/;
 		$mailid=$id;
 		if (m/\s+relay=([^\s,]*)[\s,]/) { $mail{$id}{'relay_r'}=$1; }
 		elsif (m/\s+mailer=local/) { $mail{$id}{'relay_r'}='localhost'; }
@@ -337,11 +366,18 @@ while (<>) {
 		elsif (/, stat\=Local\s+configuration/) { $mail{$id}{'code'}=451; }
 		elsif (/, stat\=Deferred:\s+(\d*)/) { $mail{$id}{'code'}=$1; }
 		else { $mail{$id}{'code'}=999; }
+			$mail{$mailid}{'year'}=$year; ### <CJK>###
 		$mail{$id}{'mon'}=$mon;
 		$mail{$id}{'day'}=$day;
 		$mail{$id}{'time'}=$time;
-		$mail{$id}{'to'}=&trim($to);
-		$mail{$id}{'from'}=&trim($from);
+		if (&trim($to)=~/^|/) {
+			# In particular case of mails are sent to a pipe, the ctladdr contains the to
+			$mail{$id}{'to'}=&trim($fromorto);
+		} else {
+			# In most cases
+			$mail{$id}{'to'}=&trim($to);
+			$mail{$id}{'from'}=&trim($fromorto);
+		}
 		if (! defined($mail{$id}{'size'})) { $mail{$id}{'size'}='?'; }
 		debug("For id=$id, found a sendmail outgoing message: to=$mail{$id}{'to'} from=$mail{$id}{'from'} size=$mail{$id}{'size'} relay_r=".($mail{$id}{'relay_r'}||''));
  	}
@@ -352,8 +388,8 @@ while (<>) {
 	elsif (/info msg .* from/) {
 		# Example: Sep 14 09:58:09 gandalf qmail: 1063526289.292776 info msg 270182: bytes 10712 from <john@john.do> qp 54945 uid 82
 		$MailType||='qmail';
-		#my ($id,$size,$from)=m/(\d+)(?:\.\d+)? info msg \d+: bytes (\d+) from <(.*)>/;
-		my ($id,$size,$from)=m/\d+(?:\.\d+)? info msg (\d+): bytes (\d+) from <(.*)>/;
+		#my ($id,$size,$from)=m/info msg \d+: bytes (\d+) from <(.*)>/;
+		my ($id,$size,$from)=m/info msg (\d+): bytes (\d+) from <(.*)>/;
 		$mailid=$id;
 		delete $mail{$mailid};	# If 'info msg' found, we start a new mail. This is to protect from wrong file
 		if (! $mail{$id}{'from'} || $mail{$id}{'from'} ne '<>') { $mail{$id}{'from'}=$from; }	# TODO ???
@@ -369,7 +405,7 @@ while (<>) {
 		# sm-mta:  Jul 28 06:55:13 androneda sm-mta[28877]: h6SDtCtg028877: from=<xxx@mysite.net>, size=2556, class=0, nrcpts=1, msgid=<w1$kqj-9-o2m45@0h2i38.4.m0.5u>, proto=ESMTP, daemon=MTA, relay=smtp.easydns.com [205.210.42.50]
 		# postfix: Jul  3 15:32:26 apollon postfix/qmgr[13860]: 08FB63B8A4: from=<nobody@ns3744.ovh.net>, size=3302, nrcpt=1 (queue active)
 		# postfix: Sep 24 14:45:15 wideboy postfix/qmgr[22331]: 7E0E6196: from=<xxx@hotmail.com>, size=1141 (queue active)
-		my ($id,$from,$size)=m/\w+\s+\d+\s+\d+:\d+:\d+\s+[\w\-]+\s+(?:sm-mta|sendmail(?:-in|)|postfix\/qmgr|postfix\/nqmgr)\[\d+\]:\s+(.*?):\s+from=(.*?),\s+size=(\d+)/;
+		my ($id,$from,$size)=m/\w+\s+\d+\s+\d+:\d+:\d+\s+[\w\-\.\@]+\s+(?:sm-mta|sendmail(?:-in|)|postfix\/qmgr|postfix\/nqmgr)\[\d+\]:\s+(.*?):\s+from=(.*?),\s+size=(\d+)/;
 		$mailid=$id;
 		if (! $mail{$id}{'code'}) { $mail{$id}{'code'}=1; }	# If not already defined, we define it
 		if (! $mail{$id}{'from'} || $mail{$id}{'from'} ne '<>') { $mail{$id}{'from'}=$from; }
@@ -381,8 +417,8 @@ while (<>) {
 	#
 	# Matched exchange message
 	#
-	elsif (/^([^\t]+)\t([^\t]+)\t[^\t]+\t([^\t]+)\t([^\t]+)\t([^\t]+)\t[^\t]+\t([^\t]+)\t([^\t]+)\t([^\t]+)\t[^\t]+\t[^\t]+\t([^\t]+)\t[^\t]+\t[^\t]+\t[^\t]+\t[^\t]+\t[^\t]+\t[^\t]+\t([^\t]+)/) {
-		#    date      hour GMT  ip_s    relay_s   partner   relay_r   ip_r    to        code      id                        size                                                      from
+	elsif (/^([^\t]+)\t([^\t]+)\t[^\t]+\t([^\t]+)\t([^\t]+)\t([^\t]+)\t[^\t]+\t([^\t]+)\t([^\t]+)\t([^\t]+)\t[^\t]+\t[^\t]+\t([^\t]+)\t[^\t]+\t[^\t]+\t[^\t]+\t[^\t]+\t[^\t]+\t([^\t]+)\t([^\t]+)/) {
+		#    date      hour GMT  ip_s    relay_s   partner   relay_r   ip_r    to        code      id                        size                                              subject   from
 		# Example: 2003-8-12	0:58:14 GMT	66.218.66.69	n14.grp.scd.yahoo.com	-	PACKRAT	192.168.1.2	christina@pirnie.org	1019	bh9e3f+5qvo@eGroups.com	0	0	4281	1	2003-8-12 0:58:14 GMT	0	Version: 6.0.3790.0	-	 [SRESafeHaven] Re: More Baby Stuff	jtluvs2cq@wmconnect.com	-
 		$MailType||='exchange';
 		my $date=$1;
@@ -394,24 +430,33 @@ while (<>) {
 		my $code=$7;
 		my $id=$8;
 		my $size=$9;
-		my $from=$10; $from =~ s/\s/%20/g;
+		my $subject=&trim($10);
+		my $from=$11; $from =~ s/\s/%20/g;
+		$id=sprintf("%s_%s_%s",$id,$from,$to);
 		# Check if record is significant record
 		my $ok=0;
-		# Code 1031=end outbound transfer
-		if ($code == 1031) {	# This is outbound mail
+
+		# Code 1031=SMTP End Outbound Transfer
+		if ($code == 1031) {	# This is for external bound mails
 			$ok=1;
-			#my $savrelay_s=$relay_s;
-			#$relay_s=$relay_r; $relay_r=$savrelay_s;
-			$relay_s=$relay_r;
-			$relay_r=$partner;
+			my $savrelay_s=$relay_s;
+			$relay_s=$relay_r; $relay_r=$savrelay_s;
+			#$relay_s=$relay_r;
+			#$relay_r=$partner;
 			$code=1;
 		}
-		# Code 1023=SMTP local delivery
-		if ($code == 1023) {	# This is inbound ???
+		# Code 1028=SMTP Store Driver: Message Delivered Locally to Store
+		if ($code == 1028) {	# This is for local bound mails
 			$code=1;
 			$ok=1;
 		}
-		if ($ok) {		
+		# Code 1030=SMTP: Non-Delivered Report (NDR) Generated
+		if ($code == 1030) {	# This is for errors. 
+			$code=999;
+			$ok=1;
+		}
+
+		if ($ok && !$mail{$id}{'code'} ) {		
 			$mailid=$id;
 			if ($date =~ /(\d+)-(\d+)-(\d+)/) {
 				$mail{$id}{'year'}=sprintf("%02s",$1);
@@ -421,6 +466,9 @@ while (<>) {
 			if ($time =~ /^(\d+):(\d+):(\d+)/) {
 				$mail{$id}{'time'}=sprintf("%02s:%02s:%02s",$1,$2,$3);
 			}
+			if ( $from eq '<>' && $subject =~ /^Delivery\s+Status/) {
+				$from='postmaster@localhost';
+			}
 			$mail{$id}{'from'}=$from;
 			$mail{$id}{'to'}=$to;
 			$mail{$id}{'code'}=$code;
@@ -432,10 +480,12 @@ while (<>) {
 	}
 
 	#
-	# Matched sendmail/postfix "to" message
+	# Matched sendmail or postfix "to" message
 	#
 	elsif (/: to=.*stat(us)?=sent/i) {
-		my ($mon,$day,$time,$id,$to)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-]+\s+(?:sm-mta|sendmail(?:-out|)|postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[.*?\]:\s+(.*?):\s+to=(.*?),/;
+		# Example:
+		# postfix:  Jan 01 07:27:38 apollon postfix/local[1689]: 2BC793B8A4: to=<jo@jo.com>, orig_to=<webmaster@toto.com>, relay=local, delay=6, status=sent ("|/usr/bin/procmail")
+		my ($mon,$day,$time,$id,$to)=m/(\w+)\s+(\d+)\s+(\d+:\d+:\d+)\s+[\w\-\.\@]+\s+(?:sm-mta|sendmail(?:-out|)|postfix\/(?:local|lmtp|smtpd|smtp|virtual|pipe))\[.*?\]:\s+(.*?):\s+to=(.*?),/;
 		$mailid=$id;
 		$mail{$id}{'code'}='1';
 		if (m/\s+relay=([^\s,]*)[\s,]/) { $mail{$id}{'relay_r'}=$1; }
@@ -454,6 +504,7 @@ while (<>) {
 			else {
 				$mail{$id}{'to'}=&trim($to);
 			}
+			$mail{$mailid}{'year'}=$year; ### <CJK>###
 			$mail{$id}{'mon'}=$mon;
 			$mail{$id}{'day'}=$day;
 			$mail{$id}{'time'}=$time;
