@@ -3,7 +3,7 @@
 # If you want to add MIME types,
 # you must add an entry in MimeFamily and may be MimeHashLib
 #-------------------------------------------------------
-# $Revision: 1.25 $ - $Author: eldy $ - $Date: 2009/09/05 11:44:25 $
+# $Revision: 1.20 $ - $Author: eldy $ - $Date: 2005/01/21 22:49:05 $
 
 
 #package AWSMIME;
@@ -14,35 +14,25 @@
 #---------------------------------------------------------------
 %MimeHashLib = (
 'text',      'Text file',
-'page',      'HTML or XML static page',
-'script',    'Dynamic Html page or Script file',
-'pl',        'Dynamic Perl Script file',
-'php',       'Dynamic PHP Script file',
+'page',      'HTML&nbsp;or&nbsp;XML&nbsp;static&nbsp;page',
+'script',    'Dynamic&nbsp;Html&nbsp;page&nbsp;or&nbsp;Script&nbsp;file',
 'image',     'Image',
 'document',  'Document',
 'package',   'Package',
 'archive',   'Archive',
-'audio',     'Audio file',
-'video',     'Video file',
-'javascript','JavaScript file',
+'audio',     'Audio',
+'video',     'Video',
+'javascript','Javascript file',
 'vbs',       'Visual Basic script',
 'conf',      'Config file',
 'css',       'Cascading Style Sheet file',
-'xsl',       'Extensible Stylesheet Language file',
-'runtime',   'Binary runtime',
+'xsl',       'Extensible&nbsp;Stylesheet&nbsp;Language&nbsp;file',
+'runtime',   'HTML&nbsp;dynamic&nbsp;page&nbsp;or&nbsp;Binary&nbsp;runtime',
 'library',   'Binary library',
-'swf',       'Adobe Flash Animation',
-'flv',       'Adobe Flash Video',
+'swf',       'Macromedia Flash Animation',
 'dtd',       'Document Type Definition',
 'csv',       'Comma Separated Value file',
 'jnlp',      'Java Web Start launch file',
-'lit',       'Microsoft Reader e-book',
-'svg',       'Scalable Vector Graphics',
-'ai',        'Adobe Illustrator file',
-'phshop',    'Adobe Photoshop image file',
-'ttf',       'TrueType scalable font file',
-'fon',       'Font file',
-'pdf',       'Adobe Acrobat file',
 );
 
 # MimeHashIcon
@@ -52,18 +42,13 @@
 %MimeHashIcon = (
 # Text file
 'txt','text',
-'log','text',
 # HTML Static page
 'html','html',
 'htm','html',
 'hdml','html',
 'wml','html',
 'wmlp','html',
-'xhtml','html',
 'xml','html',
-'vak','glasses',
-'sgm','html',
-'sgml','html',
 # HTML Dynamic pages or script
 'asp','script',
 'aspx','script', 
@@ -72,10 +57,10 @@
 'jsp','script',
 'cgi','script',
 'ksh','script',
-'php','php',
-'php3','php',
-'php4','php',
-'pl','pl',
+'php','script',
+'php3','script',
+'php4','script',
+'pl','script',
 'py','script',
 'sh','script',
 'shtml','html',
@@ -87,26 +72,18 @@
 'bmp','image',
 'jpg','image',
 'jpeg','image',
-'cdr','image',
-'ico','image',
-'svg','svg',
-'psd','phshop',
 # Document
 'doc','doc',
-'wmz','doc',
-'rtf','doc',
 'pdf','pdf',
-'xls','xls',
-'ppt','ppt',
-'pps','ppt',
+'xls','other',
+'ppt','other',
+'pps','other',
 'sxw','other',
 'sxc','other',
 'sxi','other',
 'sxd','other',
 'csv','other',
 'xsl','html',
-'lit','lit',
-'ai','ai',
 # Package
 'rpm',($LogType eq 'S'?'audio':'archive'),
 'deb','archive',
@@ -134,45 +111,33 @@
 'mp4','video',
 'mpeg','video',
 'mpg','video',
-'rm','real',
-'swf','flash',
-'flv','flash',
-'wmv','video',
-'mov','quicktime',
-'qt','quicktime',
+'rm','video',
+'swf','video',
 # Web scripts
-'js','jscript',
-'vbs','jscript',
+'js','other',
+'vbs','other',
 # Config
 'cf','other',
 'conf','other',
-'css','css',
+'css','other',
 'ini','other',
 'dtd','other',
 # Program
 'exe','script',
 'dll','script',
 'jnlp','jnlp',
-# Fonts
-'ttf','ttf',
-'fon','fon',
 );
 
 
 %MimeHashFamily=(
 # Text file
-'txt','text',
-'log','text',
+'txt','page',
 # HTML Static page
 'html','page',
 'htm','page',
 'wml','page',
 'wmlp','page',
-'xhtml','page',
 'xml','page',
-'vak','page',
-'sgm','page',
-'sgml','page',
 # HTML Dynamic pages or script
 'asp','script',
 'aspx','script', 
@@ -181,10 +146,10 @@
 'jsp','script',
 'cgi','script',
 'ksh','script',
-'php','php',
-'php3','php',
-'php4','php',
-'pl','pl',
+'php','script',
+'php3','script',
+'php4','script',
+'pl','script',
 'py','script',
 'sh','script',
 'shtml','script',
@@ -196,16 +161,9 @@
 'bmp','image',
 'jpg','image',
 'jpeg','image',
-'cdr','image',
-'ico','image',
-'svg','svg',
-'psd','phshop',
-'ai','ai',
 # Document
 'doc','document',
-'wmz','document',
-'rtf','document',
-'pdf','pdf',
+'pdf','document',
 'xls','document',
 'ppt','document',
 'pps','document',
@@ -215,7 +173,6 @@
 'sxd','document',
 'csv','csv',
 'xsl','xsl',
-'lit','lit',
 # Package
 'rpm',($LogType eq 'S'?'audio':'package'),
 'deb','package',
@@ -245,10 +202,6 @@
 'mpg','video',
 'rm','video',
 'swf','swf',
-'flv','flv',
-'wmv','video',
-'mov','video',
-'qt','video',
 # Web scripts
 'js','javascript',
 'vbs','vbs',
@@ -262,9 +215,6 @@
 'exe','runtime',
 'jnlp','jnlp',
 'dll','library',
-# Font
-'ttf','ttf',
-'fon','fon',
 );
 
 
