@@ -7,7 +7,7 @@
 #-----------------------------------------------------------------------------
 # Perl Required Modules: Geo::IP (Geo::IP::PurePerl is not yet supported)
 #-----------------------------------------------------------------------------
-# $Revision: 1.5 $ - $Author: eldy $ - $Date: 2004/12/10 22:28:39 $
+# $Revision: 1.6 $ - $Author: eldy $ - $Date: 2005/02/19 13:40:46 $
 
 
 # <-----
@@ -316,12 +316,22 @@ sub ShowInfoHost_geoip_region_maxmind {
         	my ($res1,$res2,$countryregion)=();
         	($res1,$res2)=$geoip_region_maxmind->region_by_name($param) if $geoip_region_maxmind;
         	if ($Debug) { debug("  Plugin geoip_region_maxmind: GetRegionByIp for $param: [${res1}_${res2}]",5); }
-            if ($res1 =~ /\w\w/) { print $DomainsHashIDLib{lc($res1)}||uc($res1); }
-            else { print "<span style=\"color: #$color_other\">$Message[0]</span>"; }
-            if ($res1 =~ /\w\w/ && $res2 =~ /\w\w/) {
-                print "&nbsp;(";
-                print $region{lc($res1)}{uc($res2)};
-                print ")";
+            if (! $PluginsLoaded{'init'}{'geoip'}) {
+                # Show country
+                if ($res1 =~ /\w\w/) { print $DomainsHashIDLib{lc($res1)}||uc($res1); }
+                else { print "<span style=\"color: #$color_other\">$Message[0]</span>"; }
+                # Show region
+                if ($res1 =~ /\w\w/ && $res2 =~ /\w\w/) {
+                    print "&nbsp;(";
+                    print $region{lc($res1)}{uc($res2)};
+                    print ")";
+                }
+            }
+            else {
+                if ($res1 =~ /\w\w/ && $res2 =~ /\w\w/) {
+                    print $region{lc($res1)}{uc($res2)};
+                }
+                else { print "<span style=\"color: #$color_other\">$Message[0]</span>"; }
             }
 		}
 		if ($key && $ip==6) {
@@ -331,12 +341,22 @@ sub ShowInfoHost_geoip_region_maxmind {
         	my ($res1,$res2,$countryregion)=();
         	($res1,$res2)=$geoip_region_maxmind->region_by_name($param) if $geoip_region_maxmind;
         	if ($Debug) { debug("  Plugin geoip_region_maxmind: GetRegionByName for $param: [${res1}_${res2}]",5); }
-            if ($res1 =~ /\w\w/) { print $DomainsHashIDLib{lc($res1)}||uc($res1); }
-            else { print "<span style=\"color: #$color_other\">$Message[0]</span>"; }
-            if ($res1 =~ /\w\w/ && $res2 =~ /\w\w/) {
-                print "&nbsp;(";
-                print $region{lc($res1)}{uc($res2)};
-                print ")";
+            if (! $PluginsLoaded{'init'}{'geoip'}) {
+                # Show country
+                if ($res1 =~ /\w\w/) { print $DomainsHashIDLib{lc($res1)}||uc($res1); }
+                else { print "<span style=\"color: #$color_other\">$Message[0]</span>"; }
+                # Show region
+                if ($res1 =~ /\w\w/ && $res2 =~ /\w\w/) {
+                    print "&nbsp;(";
+                    print $region{lc($res1)}{uc($res2)};
+                    print ")";
+                }
+            }
+            else {
+                if ($res1 =~ /\w\w/ && $res2 =~ /\w\w/) {
+                    print $region{lc($res1)}{uc($res2)};
+                }
+                else { print "<span style=\"color: #$color_other\">$Message[0]</span>"; }
             }
 		}
 		print "</td>";
